@@ -9,14 +9,18 @@ sub ID { 'compressed' }
 sub SHORT_DESC { "Variations on content compression" }
 sub LONG_DESC { return <<'DESC'; }
 Compression of Content is usueally done with a Content-Encoding header and a
-value of 'gzip' or 'deflate'. There are two kinds of 'deflate' encoding which
-use the same Content-Encoding value. 
-Some browsers also support compression with the Transfer-Encoding header, which
-is actually specified in the HTTP RFC. 
+value of 'gzip' (RFC1952) or 'deflate' (RFC1951). Most browsers additionally 
+accept RFC1950 compressed data for 'deflate'.
+Some browsers also support compression with the Transfer-Encoding header, 
+which is actually specified in the HTTP RFC, but most browsers don't.
 Some browsers just guess the encoding, e.g. accept gzip even if deflate is
 specified.
 And some browsers accept x-gzip and x-deflate specifications, and some even
 specifications like "x gzip" or "gzip x".
+Most browsers accept multiple content-encoding headers, even if it does not
+make much sense to compress content twice with the same encoding.
+
+Details see http://noxxi.de/research/unusual-http-content-encoding.html
 DESC
 my @tests; # set below
 sub TESTS { @tests }
@@ -26,8 +30,13 @@ my @good = (
     [ 'ce:gzip,gzip' => 'content-encoding gzip'],
     [ 'ce:x-gzip,gzip' => 'content-encoding x-gzip == gzip'],
     [ 'ce:deflate,deflate' => 'content-encoding deflate'],
-    [ 'ce:deflate,deflate-alt' => 'content-encoding deflate with IE style deflate'],
+    [ 'ce:deflate,deflate-raw' => 'content-encoding deflate with RFC1950 style deflate'],
     [ 'ce:nl-gzip,gzip' => 'content-encoding header with continuation line'],
+    [ 'ce:gzip,ce:gzip,gzip,gzip' => 'double gzip, double content-encoding header'],
+    [ 'ce:deflate,ce:deflate,deflate,deflate' => 'double deflate, double content-encoding header'],
+    [ 'ce:gzip,ce:deflate,gzip,deflate' => 'gzip+deflate, both content-encoding header'],
+    [ 'ce:deflate,ce:gzip,deflate,gzip' => 'deflate+gzip, both content-encoding header'],
+
 );
 
 # these should be fine according to RTC, but it is not supported in all browsers
@@ -39,13 +48,17 @@ my @bad_goodies = (
 # and the bad ones
 my @bad = (
     [ 'ce:x-deflate,deflate' => 'content-encoding x-deflate'],
-    [ 'ce:x-deflate,deflate-alt' => 'content-encoding x-deflate with IE style deflate'],
+    [ 'ce:x-deflate,deflate-raw' => 'content-encoding x-deflate with RFC1950 style deflate'],
     [ 'ce:gzipx,gzip' => 'content-encoding gzipx != gzip' ],
     [ 'ce:xgzip,gzip' => 'content-encoding xgzip != gzip' ],
     [ 'ce:gzip_x,gzip' => 'content-encoding "gzip x" != gzip' ],
     [ 'ce:x_gzip,gzip' => 'content-encoding "x gzip" != gzip' ],
     [ 'ce:deflate,gzip' => 'content-encoding deflate with gzipped encoding'],
     [ 'ce:gzip,deflate' => 'content-encoding gzip with deflate encoding'],
+    [ 'ce:deflate,ce:gzip,gzip,deflate' => 'gzip+deflate, both content-encoding header but wrong order'],
+    [ 'ce:gzip,ce:deflate,deflate' => 'gzip+deflate content-encoding header but only deflated'],
+    [ 'ce:deflate,ce:gzip,deflate' => 'deflate+gzip content-encoding header but only deflated'],
+    [ 'ce:deflate,ce:gzip' => 'deflate+gzip content-encoding header but no encoding'],
 );
 
 
@@ -70,9 +83,9 @@ sub make_response {
 	    $hdr .= "\r\n";
 	} elsif ( $_ eq 'gzip' ) {
 	    $data = Compress::Zlib::memGzip($data);
-	} elsif ( m{^deflate(-alt)?$} ) {
+	} elsif ( m{^deflate(-raw)?$} ) {
 	    my $zlib = Compress::Raw::Zlib::Deflate->new(
-		-WindowBits => $1 ? -MAX_WBITS() : +MAX_WBITS(),
+		-WindowBits => $1 ? +MAX_WBITS() : -MAX_WBITS(),
 		-AppendOutput => 1,
 	    );
 	    my $newdata = '';
